Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorArto Kitula <arto.kitula@gmail.com>2018-08-11 01:45:46 +0300
committerArto Kitula <arto.kitula@gmail.com>2018-08-11 01:45:46 +0300
commit544bd49e63a199a917767f735ab1fb989c83742a (patch)
treecf1811e3b3b9bc037d8918fa540dd4625f353c28
parenteae4539bddda1561e6a24790b2ef62a2576746a9 (diff)
deplibs: python use pkg-config from homebrew for ssl + xz
-rw-r--r--build_files/build_environment/cmake/python.cmake10
1 files changed, 5 insertions, 5 deletions
diff --git a/build_files/build_environment/cmake/python.cmake b/build_files/build_environment/cmake/python.cmake
index 6b3c25d32bf..d24cfa1f590 100644
--- a/build_files/build_environment/cmake/python.cmake
+++ b/build_files/build_environment/cmake/python.cmake
@@ -61,12 +61,12 @@ if(WIN32)
message("POutput = ${PYTHON_OUTPUTDIR}")
else()
if(APPLE)
- # we need to manually add homebrew headers to get ssl module building
- set(PYTHON_CFLAGS "-I/usr/local/opt/openssl/include -I${OSX_SYSROOT}/usr/include ${PLATFORM_CFLAGS}")
- set(PYTHON_LDFLAGS "-L/usr/local/opt/openssl/lib ${PLATFORM_LDFLAGS}")
- set(PYTHON_CONFIGURE_ENV ${CONFIGURE_ENV} && export CFLAGS=${PYTHON_CFLAGS} && export LDFLAGS=${PYTHON_LDFLAGS})
+ # we need to add homebrew pkgconfig directories to get ssl, xz
+
+ set(BREW_PKG_CONFIG "/usr/local/opt/openssl/lib/pkgconfig:/usr/local/opt/xz/lib/pkgconfig")
+ set(PYTHON_CONFIGURE_ENV ${CONFIGURE_ENV} && export PKG_CONFIG_PATH=${BREW_PKG_CONFIG})
set(PYTHON_BINARY ${BUILD_DIR}/python/src/external_python/python.exe)
- set(PYTHON_PATCH ${PATCH_CMD} --verbose -p 0 -d ${BUILD_DIR}/python/src/external_python < ${PATCH_DIR}/python_apple.diff)
+ set(PYTHON_PATCH echo .)
else()
set(PYTHON_CONFIGURE_ENV ${CONFIGURE_ENV})
set(PYTHON_BINARY ${BUILD_DIR}/python/src/external_python/python)